use chrono::{Local, TimeZone};
use r701::R701;
use std::collections::HashMap;

fn main() {
    let start = Local.with_ymd_and_hms(1970, 1, 1, 0, 0, 0).unwrap();
    let end = Local.with_ymd_and_hms(9999, 1, 1, 0, 0, 0).unwrap();
    let mut names = HashMap::new();

    let mut r701 = R701::connect("127.0.0.1:5005").unwrap();

    println!("No\tMchn\tEnNo\t\tName\t\tMode\tIOMd\tDateTime\t");
    r701.into_record_iter()
        .unwrap()
        .take_while(|record| record.datetime >= start)
        .skip_while(|record| record.datetime >= end)
        .collect::<Vec<_>>()
        .iter()
        .rev()
        .enumerate()
        .for_each(|(id, record)| {
            let name = names.entry(record.employee_id).or_insert_with(|| {
                r701.get_name(record.employee_id)
                    .unwrap()
                    .unwrap_or(format!("user #{}", record.employee_id))
            });

            println!(
                "{:0>6}\t{}\t{:0>9}\t{: <10}\t{}\t{}\t{}",
                id + 1,
                1,
                record.employee_id,
                name,
                35,
                record.clock as u8,
                record.datetime.format("%Y/%m/%d  %H:%M:%S"),
            );
        });
}
